@@ -14,10 +14,12 @@ merge serialport => 0;
 merge mem => undef;
 merge cpus => undef;
 merge acpi => 1;
+merge usb => 0;
 merge vnc => undef;
 merge tablet => undef;
 merge platform => 'bios';
 merge ovmfdir => '/usr/share/OVMF';
+merge chipset;
 merge statedir;
 merge rundir;
 merge kvm;
@@ -40,6 +42,10 @@ sub set_vnc {
 	$self->vnc(bool(shift));
 }
 
+sub set_usb {
+	$self->usb(bool(shift));
+}
+
 sub set_tablet {
 	$self->tablet(bool(shift));
 }
@@ -95,6 +101,10 @@ sub set_platform {
 	}
 }
 
+sub set_chipset {
+	$self->chipset(shift);
+}
+
 sub set_ovmfdir {
 	my $value = shift;
 	die "OVMF directory '$value' does not exist\n" unless -e $value;
